@@ -1,7 +1,7 @@
 import unittest
 from os.path import exists
 
-from DocsteadyTestUtils import read_test_data
+from DocsteadyTestUtils import getTprData, read_test_data
 
 from docsteady.config import Config
 from docsteady.formatters import alphanum_map_array_sort, alphanum_map_sort
@@ -13,6 +13,9 @@ from docsteady.tplan import render_report
 # from DocsteadyTestUtils import getExecutionsData, getTprData
 
 
+GET_DATA = False
+
+
 class TestTPR(unittest.TestCase):
     def test_gen(self) -> None:
         # plan = "LVV-P63"
@@ -24,11 +27,12 @@ class TestTPR(unittest.TestCase):
 
         Config.CACHED_POINTERS = read_test_data("POINTERS")
 
-        # getExecutionsData([27531072, 27531013, 27531080])
+        if GET_DATA:  # rewrite images only gets called if you get data
+            getTprData(plan)
+            # not workign getExecutionsData([27531072, 27531013, 27531080])
+            # unless the cache is full
         Config.CACHED_TEST_EXECUTIONS = read_test_data("TEST-EXECUTIONS")
 
-        # getTprData(plan)
-
         plan_dict = read_test_data(f"TPR-{plan}")
         # the next updates the sorted result inside the map
         alphanum_map_array_sort(plan_dict["test_results_map"])
@@ -103,9 +107,13 @@ class TestTPR(unittest.TestCase):
                         if "script_results" in run:
                             print(
                                 f"{test_item['key']} - has  "
-                                f"{len(run['script_results']) } "
+                                f"{len(run['script_results'])} "
                                 f"script results "
                             )
+                            for res in run["script_results"]:
+                                if "cloudfront" in res["actual_result"]:
+                                    print(f'URL NONO - {res["actual_result"]}')
+                                    ok = False
                         else:
                             print(
                                 f"{test_item['key']} - has  no script results "
@@ -114,7 +122,7 @@ class TestTPR(unittest.TestCase):
                     for tresult in testresults_map[cycle["key"]].values():
                         print(
                             f" Details {cycle['key']}-{test_item['key']} "
-                            f"{tresult['key']}-{tresult['id']}:"
+                            f"{tresult['key']}-{tresult['id']}: "
                         )
                         for script_result in tresult["sorted"]:
                             print(
